Type: Package
Package: tufte
Title: Tufte's Styles for R Markdown Documents
Version: 0.15.0
Authors@R: c(
    person("Yihui", "Xie", role = "aut", email = "xie@yihui.name", comment = c(ORCID = "0000-0003-0645-5666")),
    person("Christophe", "Dervieux", role = c("ctb", "cre"), email = "cderv@posit.co", comment = c(ORCID = "0000-0003-4474-2498")),
    person("JJ", "Allaire", role = "aut"),
    person("Andrzej", "Oles", role = "ctb"),
    person("Dave", "Liepmann", role = "ctb", comment = "Tufte CSS in inst/rmarkdown/templates/tufte_html/resources"),
    person("Posit Software, PBC", role = c("cph", "fnd"), comment = c(ROR = "03wc8by49"))
  )
Description: Provides R Markdown output formats to use Tufte styles for
    PDF and HTML output.
License: GPL-3
URL: https://github.com/rstudio/tufte
BugReports: https://github.com/rstudio/tufte/issues
Imports: htmltools, knitr (>= 1.28), rmarkdown (>= 2.11), xfun (>=
        0.13)
Suggests: xml2, bookdown, covr, testthat (>= 3.1.0), tinytex, withr (>=
        2.3.0)
Config/testthat/edition: 3
Config/roxygen2/markdown: TRUE
Config/roxygen2/version: 8.0.0
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2026-05-21 15:08:54 UTC; chris
Author: Yihui Xie [aut] (ORCID: <https://orcid.org/0000-0003-0645-5666>),
  Christophe Dervieux [ctb, cre] (ORCID:
    <https://orcid.org/0000-0003-4474-2498>),
  JJ Allaire [aut],
  Andrzej Oles [ctb],
  Dave Liepmann [ctb] (Tufte CSS in
    inst/rmarkdown/templates/tufte_html/resources),
  Posit Software, PBC [cph, fnd] (ROR: <https://ror.org/03wc8by49>)
Maintainer: Christophe Dervieux <cderv@posit.co>
Repository: CRAN
Date/Publication: 2026-05-21 16:30:02 UTC
