# Generated by roxygen2: do not edit by hand

export(margin_note)
export(newthought)
export(quote_footer)
export(sans_serif)
export(tufte_book)
export(tufte_book2)
export(tufte_handout)
export(tufte_handout2)
export(tufte_html)
export(tufte_html2)
importFrom(htmltools,htmlDependency)
importFrom(knitr,is_html_output)
importFrom(knitr,is_latex_output)
