% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tufte-package.R
\docType{package}
\name{tufte-package}
\alias{tufte}
\alias{tufte-package}
\title{tufte: Tufte's Styles for R Markdown Documents}
\description{
Provides R Markdown output formats to use Tufte styles for PDF and HTML output.
}
\seealso{
Useful links:
\itemize{
  \item \url{https://github.com/rstudio/tufte}
  \item Report bugs at \url{https://github.com/rstudio/tufte/issues}
}

}
\author{
\strong{Maintainer}: Christophe Dervieux \email{cderv@posit.co} (\href{https://orcid.org/0000-0003-4474-2498}{ORCID}) [contributor]

Authors:
\itemize{
  \item Yihui Xie \email{xie@yihui.name} (\href{https://orcid.org/0000-0003-0645-5666}{ORCID})
  \item JJ Allaire
}

Other contributors:
\itemize{
  \item Andrzej Oles [contributor]
  \item Dave Liepmann (Tufte CSS in inst/rmarkdown/templates/tufte_html/resources) [contributor]
  \item Posit Software, PBC (\href{https://ror.org/03wc8by49}{ROR}) [copyright holder, funder]
}

}
\keyword{internal}
